@@ -1,7 +1,7 @@
 /*
  * Functions internal to the PV library.  Include "config.h" first.
  *
- * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023 Andrew Wood
+ * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023-2024 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
  */
@@ -105,6 +105,7 @@ struct pvstate_s {
 		bool wait;                       /* wait for data before display */
 		bool linemode;                   /* count lines instead of bytes */
 		bool bits;			 /* report bits instead of bytes */
+		bool decimal_units;		 /* use decimal prefixes */
 		bool null_terminated_lines;      /* lines are null-terminated */
 		bool no_display;                 /* do nothing other than pipe data */
 		unsigned int skip_errors;        /* skip read errors counter */
@@ -122,6 +123,8 @@ struct pvstate_s {
 		double delay_start;              /* delay before first display */
 		pid_t watch_pid;		 /* process to watch fds of */
 		int watch_fd;			 /* fd to watch */
+		int output_fd;                   /* fd to write output to */
+		/*@null@*/ char *output_name;    /* name of the output, for diagnostics */
 		unsigned int average_rate_window; /* time window in seconds for average rate calculations */
 		unsigned int width;              /* screen width */
 		unsigned int height;             /* screen height */
@@ -156,6 +159,7 @@ struct pvstate_s {
 #ifdef SA_SIGINFO
 		struct sigaction old_sigusr2;
 #endif
+		struct sigaction old_sigalrm;
 	} signal;
 
 	/*******************
