@@ -1,7 +1,7 @@
 /*
  * Output command-line help to stdout.
  *
- * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023 Andrew Wood
+ * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023-2024 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
  */
@@ -307,6 +307,9 @@ void display_help(void)
 		{ "-8", "--bits", NULL,
 		 N_("show number of bits transferred"),
 		 { 0, 0, 0, 0} },
+		{ "-k", "--si", NULL,
+		 N_("treat suffixes as multiples of 1000 rather than 1024"),
+		 { 0, 0, 0, 0} },
 		{ "-T", "--buffer-percent", NULL,
 		 N_("show percentage of transfer buffer in use"),
 		 { 0, 0, 0, 0} },
@@ -357,6 +360,9 @@ void display_help(void)
 		 N_("use cursor positioning escape sequences"),
 		 { 0, 0, 0, 0} },
 		{ "", NULL, NULL, NULL, { 0, 0, 0, 0} },
+		{ "-o", "--output", N_("FILE"),
+		 N_("write output to FILE instead of stdout"),
+		 { 0, 0, 0, 0} },
 		{ "-L", "--rate-limit", N_("RATE"),
 		 N_("limit transfer to RATE bytes per second"),
 		 { 0, 0, 0, 0} },
